@@ -7,4 +7,4 @@ es_index = get_config('elasticsearch.index')
 es_address = es_host
 if not es_address.startswith('https://'):
   es_address = f'http://{es_host}:80'
-es = AsyncElasticsearch(hosts=[es_host])
\ No newline at end of file
+es = AsyncElasticsearch(hosts=[es_address], http_compress=True)
\ No newline at end of file
